pub struct CheckResult {
pub name: String,
pub verdict: Verdict,
pub severity: Option<Severity>,
pub detail: Option<String>,
pub at: DateTime<Utc>,
pub duration_ms: Option<u64>,
}Expand description
Result of a single check.
Fields
name: StringStable identifier for the check (e.g. compile, test::round_trip).
verdict: VerdictOutcome of the check.
severity: Option<Severity>Severity when the verdict is Fail or Warn. None for Pass and Skip.
detail: Option<String>Human-readable detail. Optional.
at: DateTime<Utc>Time the check ran. UTC.
duration_ms: Option<u64>Duration of the check, in milliseconds. Optional.
Implementations
Sourceimpl CheckResult
impl CheckResult
Sourcepub fn fail(name: impl Into<String>, severity: Severity) -> Self
pub fn fail(name: impl Into<String>, severity: Severity) -> Self
Build a failing check result with the given name and severity.
Sourcepub fn warn(name: impl Into<String>, severity: Severity) -> Self
pub fn warn(name: impl Into<String>, severity: Severity) -> Self
Build a warning check result with the given name and severity.
Sourcepub fn with_detail(self, detail: impl Into<String>) -> Self
pub fn with_detail(self, detail: impl Into<String>) -> Self
Attach a human-readable detail to this check result.
Sourcepub fn with_duration_ms(self, ms: u64) -> Self
pub fn with_duration_ms(self, ms: u64) -> Self
Attach a duration measurement (milliseconds) to this check result.